==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/sheet/SubTotalColumn.hpp <==
#ifndef _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_
#define _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HDL_
#include "com/sun/star/sheet/SubTotalColumn.hdl"
#endif

#ifndef _COM_SUN_STAR_SHEET_GENERALFUNCTION_HPP_
#include "com/sun/star/sheet/GeneralFunction.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace sheet {

inline SubTotalColumn::SubTotalColumn() SAL_THROW( () )
    : Column(0)
    , Function(::com::sun::star::sheet::GeneralFunction_NONE)
{
}

inline SubTotalColumn::SubTotalColumn(const ::sal_Int32& Column_, const ::com::sun::star::sheet::GeneralFunction& Function_) SAL_THROW( () )
    : Column(Column_)
    , Function(Function_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::sheet::SubTotalColumn const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.sheet.SubTotalColumn");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/sheet/SubTotalColumn.hpp <==
#ifndef _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_
#define _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HDL_
#include "com/sun/star/sheet/SubTotalColumn.hdl"
#endif

#ifndef _COM_SUN_STAR_SHEET_GENERALFUNCTION_HPP_
#include "com/sun/star/sheet/GeneralFunction.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace sheet {

inline SubTotalColumn::SubTotalColumn() SAL_THROW( () )
    : Column(0)
    , Function(::com::sun::star::sheet::GeneralFunction_NONE)
{
}

inline SubTotalColumn::SubTotalColumn(const ::sal_Int32& Column_, const ::com::sun::star::sheet::GeneralFunction& Function_) SAL_THROW( () )
    : Column(Column_)
    , Function(Function_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace sheet {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::sheet::SubTotalColumn const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.sheet.SubTotalColumn");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::sheet::SubTotalColumn const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::sheet::SubTotalColumn >::get();
}

#endif // _COM_SUN_STAR_SHEET_SUBTOTALCOLUMN_HPP_
